#*******************************************************************************
#Licensed Materials - Property of IBM
#(c) Copyright IBM Corporation 2008, 2009. All Rights Reserved.
#
#Note to U.S. Government Users Restricted Rights:
#Use, duplication or disclosure restricted by GSA ADP Schedule
#Contract with IBM Corp.
#*******************************************************************************
#!/bin/sh

# default project area
AREA="Quality+Manager"

Usage()
{
    echo
    echo "Usage: $0 [options]"
    echo "    -h          : show this help"
    echo "    -s server   : RQM server. E.g. https://servername:9443/"
    echo "    -u username : login username"
    echo "    -p password : login password"
    echo "    -a area     : project area. Default is Quality+Manager" 
    echo
    exit 1
}

##############  Get options
while getopts "hs:p:u:a:" flag; do
    case $flag in
       "s") SERVER=$OPTARG ;;
       "u") USER=$OPTARG ;;
       "p") PASSWORD=$OPTARG ;;
       "a") AREA=$OPTARG ;;       
       "h") Usage ;;
    esac
done

if [ X$SERVER == X ]; then
    Usage
fi

if [ X$USER == X ]; then
    Usage
fi

if [ X$PASSWORD == X ]; then
    Usage
fi


##############  import the sample artifacts
BINDIR=`dirname $0`/../../tools/import
IMPORT="$BINDIR/import.sh -u $USER -p $PASSWORD -s $SERVER -i -a $AREA"

### requirements
for file in *_Req.xml
do
    $IMPORT -t requirement -f $file -n $file
done

### test scripts
for file in *_TS.xml
do
    $IMPORT -t testscript -f $file -n $file
done

### test cases
for file in *_TC.xml
do
    $IMPORT -t testcase -f $file -n $file
done

### test plans
for file in *_TP.xml
do
    $IMPORT -t testplan -f $file -n $file
done

### configuration
for file in *_CFG.xml
do
    $IMPORT -t configuration -f $file -n sampleprovider/sampleinstance/$file
done

### execution record
for file in *_TER.xml
do
    $IMPORT -t executionworkitem -f $file -n $file
done

### execution result
for file in *_ER.xml
do
    $IMPORT -t executionresult -f $file -n $file
done

### test environment
for file in *_TE.xml
do
    $IMPORT -t configuration -f $file -n $file
done

### lab resource
for file in *_LR.xml
do
    $IMPORT -t labresource -f $file -n RQM/REST/$file
done

### reservations
for file in *_RS.xml
do
    $IMPORT -t reservation -f $file -n $file
done

### requests
for file in *_RQ.xml
do
    $IMPORT -t request -f $file -n $file
done

### resource groups
for file in *_RG.xml
do
    $IMPORT -t resourcegroup  -f $file -n $file
done
